/*
 * Copyright (c) 2016-present Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0,
 * and you may not use this file except in compliance with the Apache License Version 2.0.
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Apache License Version 2.0 is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.nexus.ci.iq.IqPolicyEvaluatorWorkflowStep

import org.sonatype.nexus.ci.iq.IqApplication
import org.sonatype.nexus.ci.iq.Messages
import org.sonatype.nexus.ci.util.IqUtil

import jenkins.model.Jenkins
import lib.CredentialsTagLib
import lib.FormTagLib

def f = namespace(FormTagLib)
def c = namespace(CredentialsTagLib)

link(rel: "stylesheet", href: "${rootURL}/plugin/nexus-jenkins-plugin/css/nexus.css", type: "text/css")

if (!IqUtil.hasIqConfiguration()) {
  div(class: 'nexus-jenkins-error' ) {
    span(class: 'error') {
      yield Messages.IqPolicyEvaluation_NoIqServersConfigured()
    }
    span(class: 'nexus-spacer')
    yield Messages.IqPolicyEvaluation_AddIqServers()
    a(href: Jenkins.get().rootUrl + "manage/configure", "Configure System")
  }
}

String iqInstanceId = instance?.iqInstanceId
if ((iqInstanceId && !IqUtil.getIqConfiguration(iqInstanceId)) || !iqInstanceId) {
  iqInstanceId = IqUtil.getFirstIqConfiguration()?.id
}
f.entry(title: _('IQ Instance'), field: 'iqInstanceId') {
  f.select(value: "${iqInstanceId}")
}

f.entry(title: _(Messages.IqPolicyEvaluation_Stage()), field: 'iqStage') {
  f.select()
}

f.entry(title: _(Messages.IqPolicyEvaluation_Organization()), field: 'iqOrganization') {
  f.select()
}

f.entry(title: 'Application') {
  f.hetero_radio(field: 'iqApplication', descriptors: Jenkins.get().getDescriptorList(IqApplication.class))
}

f.entry(title: _(Messages.IqPolicyEvaluation_ScanPatterns()),
    help: descriptor.getHelpFile('iqScanPatterns'),
    class: 'reduce-margin-top') {
  f.repeatable(field: 'iqScanPatterns', minimum: '0') {
    f.textbox(field: 'scanPattern')
    f.repeatableDeleteButton()
  }
}

f.advanced(title: _(Messages.IqPolicyEvaluation_AdvancedOptions())) {
  f.section() {
    f.entry(title: _(Messages.IqPolicyEvaluation_ModuleExcludes()),
        help: descriptor.getHelpFile('iqModuleExcludes')) {
      f.repeatable(field: 'iqModuleExcludes', minimum: '0') {
        f.textbox(field: 'moduleExclude')
        f.repeatableDeleteButton()
      }
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_FailOnNetwork()), field: 'failBuildOnNetworkError') {
      f.checkbox()
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_FailOnScanningErrors()), field: 'failBuildOnScanningErrors') {
      f.checkbox()
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_UnstableOnScanningWarnings()), field: 'unstableBuildOnScanningWarnings') {
      f.checkbox()
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_JobSpecificCredentials()), field: 'jobCredentialsId') {
      c.select(context:app, includeUser:false, expressionAllowed:false)
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_EnableDebugLogging()), field: 'enableDebugLogging') {
      f.checkbox()
    }

    f.entry(title: _(Messages.IqPolicyEvaluation_AdvancedProperties()), field: 'advancedProperties') {
      f.textarea()
    }

    f.block() {
      f.validateButton(
          title: _(org.sonatype.nexus.ci.config.Messages.Configuration_TestConnection()),
          progress: _('Testing...'),
          method: 'verifyCredentials',
          with: 'iqInstanceId,jobCredentialsId'
      )
    }
  }
}

f.advanced(title: 'Reachability Analysis') {
  f.section() {
    f.property(field: 'reachability')
  }
}
